=======
Meeting
=======

.. image:: https://img.shields.io/pypi/v/meeting.svg
        :target: https://pypi.python.org/pypi/meeting

.. image:: https://travis-ci.org/mauler/meeting.svg?branch=master
        :target: https://travis-ci.org/mauler/meeting

.. image:: https://ci.appveyor.com/api/projects/status/github/mauler/meeting?branch=master
        :target: https://ci.appveyor.com/project/mauler/meeting/branch/master

.. image:: https://codecov.io/github/mauler/meeting/coverage.svg?branch=master
        :target: https://codecov.io/github/mauler/meeting?branch=master

.. image:: https://badges.gitter.im/Join Chat.svg
        :target: https://gitter.im/mauler/meeting?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. image:: https://readthedocs.org/projects/meeting/badge/?version=latest
        :target: https://readthedocs.org/projects/meeting/?badge=latest
        :alt: Documentation Status

.. image:: https://landscape.io/github/mauler/meeting/master/landscape.svg?style=flat
        :target: https://landscape.io/github/mauler/meeting/master
        :alt: Code Health

.. image:: https://img.shields.io/scrutinizer/g/mauler/meeting.svg
        :target: https://scrutinizer-ci.com/g/mauler/meeting/?branch=master
        :alt: Scrutinizer Code Quality


*****
Usage
*****

Festival management application: Tickets E-Commerce, Tickets validation on Lobby (Web, Paper, Guest, Local Purchase) and Sells on Wristband/Card (Beverage, Food, Souvenir, etc).


*************
Documentation
*************

The documenation is written in rst format. It's available on the folder *docs/*. To write or read it in realtime install the sphinx dependencies using::

    $ python -m pip install docs/requirements.txt

And then execute the docs server via the command below::

    $ make docs

Your browser will open the local docs website (Running on port 8000 by default).


*********
Thanks to
*********

Project structure, documentation generation and other stuff from these
python boilerplate package projects:

* https://github.com/fabiommendes/python-boilerplate
* https://github.com/mtchavez/python-package-boilerplate
